@@ -33,11 +33,13 @@ else:
         from typing import Reversible
 
 if sys.version_info >= (3, 9):
+    from collections.abc import ItemsView as ItemsViewType
     from collections.abc import KeysView as KeysViewType
     from collections.abc import ValuesView as ValuesViewType
 else:
     from typing import KeysView as KeysViewType
     from typing import ValuesView as ValuesViewType
+    from typing import ItemsView as ItemsViewType
 
 from . import RebuildStrategy
 from .base import (
@@ -170,12 +172,19 @@ class _DictDatabaseDriver(_SqliteCollectionBaseDatabaseDriver):
         for res in cur:
             yield cast(bytes, res[0])
 
+    @classmethod
+    def get_serialized_items(cls, table_name: str, cur: sqlite3.Cursor) -> Iterable[Tuple[bytes, bytes]]:
+        cur.execute(f"SELECT serialized_key, serialized_value FROM {table_name} ORDER BY item_order")
+        for res in cur:
+            yield (cast(bytes, res[0]), cast(bytes, res[1]))
+
 
 class _Dict(SqliteCollectionBase[KT], MutableMapping[KT, VT], Generic[KT, VT]):
     _driver_class = _DictDatabaseDriver
 
     def __init__(
         self,
+        __data: Optional[Union[Iterable[Tuple[KT, VT]], Mapping[KT, VT]]] = None,
         connection: Optional[Union[str, sqlite3.Connection]] = None,
         table_name: Optional[str] = None,
         key_serializer: Optional[Callable[[KT], bytes]] = None,
@@ -185,7 +194,7 @@ class _Dict(SqliteCollectionBase[KT], MutableMapping[KT, VT], Generic[KT, VT]):
         serializer: Optional[Callable[[VT], bytes]] = None,
         deserializer: Optional[Callable[[bytes], VT]] = None,
         persist: bool = True,
-        rebuild_strategy: RebuildStrategy = RebuildStrategy.CHECK_WITH_FIRST_ELEMENT,
+        rebuild_strategy: Optional[RebuildStrategy] = None,
         data: Optional[Union[Iterable[Tuple[KT, VT]], Mapping[KT, VT]]] = None,
     ) -> None:
         if serializer is not None:
@@ -224,9 +233,17 @@ class _Dict(SqliteCollectionBase[KT], MutableMapping[KT, VT], Generic[KT, VT]):
             persist=persist,
             rebuild_strategy=rebuild_strategy,
         )
-        if data is not None:
+        if data is not None or __data is not None:
             self.clear()
-            self.update(data)
+            if data is not None:
+                warnings.warn(
+                    "data keyword argument is deprecated and will be removed in version 1.0.0",
+                    DeprecationWarning,
+                    stacklevel=2,
+                )
+                self.update(data)
+            if __data is not None:
+                self.update(__data)
 
     @property
     def key_serializer(self) -> Callable[[KT], bytes]:
@@ -339,6 +356,7 @@ class _Dict(SqliteCollectionBase[KT], MutableMapping[KT, VT], Generic[KT, VT]):
     ) -> "Dict[KT, VT]":
 
         return Dict[KT, VT](
+            (self if data is None else data),
             connection=self.connection,
             key_serializer=self.key_serializer,
             key_deserializer=self.key_deserializer,
@@ -346,7 +364,6 @@ class _Dict(SqliteCollectionBase[KT], MutableMapping[KT, VT], Generic[KT, VT]):
             value_deserializer=self.value_deserializer,
             rebuild_strategy=RebuildStrategy.SKIP,
             persist=False,
-            data=(self if data is None else data),
         )
 
     def copy(self) -> "Dict[KT, VT]":
@@ -458,6 +475,9 @@ class _Dict(SqliteCollectionBase[KT], MutableMapping[KT, VT], Generic[KT, VT]):
     def values(self) -> "ValuesView[VT]":
         return ValuesView[VT](cast(Dict[KT, VT], self))
 
+    def items(self) -> "ItemsView[KT, VT]":
+        return ItemsView[KT, VT](cast(Dict[KT, VT], self))
+
 
 if sys.version_info >= (3, 8):
 
@@ -473,13 +493,13 @@ if sys.version_info >= (3, 9):
     class Dict(_ReversibleDict[KT, VT]):
         def __or__(self, other: Mapping[KT, VT]) -> "Dict[KT, VT]":
             tmp = Dict(
+                self,
                 connection=self.connection,
                 key_serializer=self.key_serializer,
                 key_deserializer=self.key_deserializer,
                 value_serializer=self.value_serializer,
                 value_deserializer=self.value_deserializer,
                 persist=self.persist,
-                data=self,
             )
             tmp |= other
             return tmp
@@ -513,20 +533,20 @@ class KeysView(MappingView, KeysViewType[_KT_co], Generic[_KT_co]):
 
     def __and__(self, o: Iterable[Any]) -> sc_Set[_KT_co]:  # type: ignore[override]
         return sc_Set[_KT_co](
+            (d for d in o if d in self._parent),
             connection=self._parent.connection,
             serializer=self._parent.key_serializer,
             deserializer=self._parent.key_deserializer,
             persist=False,
-            data=(d for d in o if d in self._parent),
         )
 
     def __rand__(self, o: Iterable[_T]) -> sc_Set[_T]:  # type: ignore[override]
         return sc_Set[_T](
+            (d for d in o if d in self._parent),
             connection=self._parent.connection,
             serializer=self._parent.key_serializer,
             deserializer=self._parent.key_deserializer,
             persist=False,
-            data=(d for d in o if d in self._parent),
         )
 
     def __contains__(self, o: object) -> bool:
@@ -542,11 +562,11 @@ class KeysView(MappingView, KeysViewType[_KT_co], Generic[_KT_co]):
 
     def __or__(self, o: Iterable[_T]) -> sc_Set[Union[_KT_co, _T]]:  # type: ignore[override]
         return sc_Set[Union[_KT_co, _T]](
+            itertools.chain(self._parent, o),
             connection=self._parent.connection,
             serializer=self._parent.key_serializer,
             deserializer=self._parent.key_deserializer,
             persist=False,
-            data=itertools.chain(self._parent, o),
         )
 
     def __ror__(self, o: Iterable[_T]) -> sc_Set[Union[_KT_co, _T]]:  # type: ignore[override]
@@ -554,29 +574,29 @@ class KeysView(MappingView, KeysViewType[_KT_co], Generic[_KT_co]):
 
     def __sub__(self, o: Iterable[Any]) -> sc_Set[_KT_co]:  # type: ignore[override]
         return sc_Set[KT](
+            self._parent,
             connection=self._parent.connection,
             serializer=self._parent.key_serializer,
             deserializer=self._parent.key_deserializer,
             persist=False,
-            data=self._parent,
         ).difference(o)
 
     def __rsub__(self, o: Iterable[_T]) -> sc_Set[_T]:  # type: ignore[override]
         return sc_Set[_T](
+            o,
             connection=self._parent.connection,
             serializer=self._parent.key_serializer,
             deserializer=self._parent.key_deserializer,
             persist=False,
-            data=o,
         ).difference(self._parent)
 
     def __xor__(self, o: Iterable[_T]) -> sc_Set[Union[_KT_co, _T]]:  # type: ignore[override]
         return sc_Set[Union[KT, _T]](
+            self._parent,
             connection=self._parent.connection,
             serializer=self._parent.key_serializer,
             deserializer=self._parent.key_deserializer,
             persist=False,
-            data=self._parent,
         ).symmetric_difference(o)
 
     def __rxor__(self, o: Iterable[_T]) -> sc_Set[Union[_KT_co, _T]]:  # type: ignore[override]
@@ -604,3 +624,104 @@ class ValuesView(MappingView, ValuesViewType[_VT_co], Generic[_VT_co]):
             cur = self._parent.connection.cursor()
             for sv in self._parent._driver_class.get_reversed_serialized_values(self._parent.table_name, cur):
                 yield self._parent.deserialize_value(sv)
+
+
+class ItemsView(MappingView, ItemsViewType[_KT_co, _VT_co]):
+    def _item_serializer(self, o: Tuple[_KT_co, _VT_co]) -> bytes:
+        if not is_hashable(o[1]):
+            raise TypeError(f"unhashable type: '{type(o[1]).__name__}'")
+        return SqliteCollectionBase[Tuple[bytes, bytes]]._default_serializer(
+            (self._parent.serialize_key(o[0]), self._parent.serialize_value(o[1]))
+        )
+
+    def _item_deserializer(self, o: bytes) -> Tuple[_KT_co, _VT_co]:
+        sk, sv = SqliteCollectionBase[Tuple[bytes, bytes]]._default_deserializer(o)
+        return (self._parent.deserialize_key(sk), self._parent.deserialize_value(sv))
+
+    def __init__(self, mapping: Dict[_KT_co, _VT_co]) -> None:
+        super(ItemsView, self).__init__(mapping)
+
+    def __and__(self, o: Iterable[Any]) -> sc_Set[Tuple[_KT_co, _VT_co]]:  # type: ignore[override]
+        tmp = sc_Set[Tuple[_KT_co, _VT_co]](
+            iter(self),
+            connection=self._parent.connection,
+            serializer=self._item_serializer,
+            deserializer=self._item_deserializer,
+            persist=False,
+        )
+        return sc_Set[Tuple[_KT_co, _VT_co]](
+            (cast(Tuple[_KT_co, _VT_co], d) for d in o if d in tmp),
+            connection=self._parent.connection,
+            serializer=self._item_serializer,
+            deserializer=self._item_deserializer,
+            persist=False,
+        )
+
+    def __rand__(self, o: Iterable[_T]) -> sc_Set[_T]:  # type: ignore[override]
+        return cast(sc_Set[_T], self & o)
+
+    def __contains__(self, o: object) -> bool:
+        if not isinstance(o, tuple) or len(o) != 2 or o[0] not in self._parent:
+            return False
+        return bool(self._parent[o[0]] == o[1])
+
+    def __iter__(self) -> Iterator[Tuple[_KT_co, _VT_co]]:
+        cur = self._parent.connection.cursor()
+        for sk, sv in self._parent._driver_class.get_serialized_items(self._parent.table_name, cur):
+            yield self._parent.deserialize_key(sk), self._parent.deserialize_value(sv)
+
+    if sys.version_info >= (3, 8):
+
+        def __reversed__(self) -> Iterator[Tuple[_KT_co, _VT_co]]:
+            ...
+
+    def __or__(self, o: Iterable[_T]) -> sc_Set[Union[Tuple[_KT_co, _VT_co], _T]]:  # type: ignore[override]
+        return sc_Set[Union[Tuple[_KT_co, _VT_co], _T]](
+            itertools.chain(self, o),
+            connection=self._parent.connection,
+            serializer=cast(Callable[[Union[Tuple[_KT_co, _VT_co], _T]], bytes], self._item_serializer),
+            deserializer=cast(Callable[[bytes], Union[Tuple[_KT_co, _VT_co], _T]], self._item_deserializer),
+            persist=False,
+        )
+
+    def __ror__(self, o: Iterable[_T]) -> sc_Set[Union[Tuple[_KT_co, _VT_co], _T]]:  # type: ignore[override]
+        return self | o
+
+    def __sub__(self, o: Iterable[Any]) -> sc_Set[Tuple[_KT_co, _VT_co]]:  # type: ignore[override]
+        tmp = sc_Set[Tuple[_KT_co, _VT_co]](
+            iter(self),
+            connection=self._parent.connection,
+            serializer=self._item_serializer,
+            deserializer=self._item_deserializer,
+            persist=False,
+        )
+        tmp.difference_update(o)
+        return tmp
+
+    def __rsub__(self, o: Iterable[_T]) -> sc_Set[_T]:  # type: ignore[override]
+        tmp = sc_Set[Tuple[_KT_co, _VT_co]](
+            iter(self),
+            connection=self._parent.connection,
+            serializer=self._item_serializer,
+            deserializer=self._item_deserializer,
+            persist=False,
+        )
+        return sc_Set[_T](
+            (d for d in o if d not in tmp),
+            connection=self._parent.connection,
+            persist=False,
+        )
+
+    def __xor__(self, o: Iterable[_T]) -> sc_Set[Union[Tuple[_KT_co, _VT_co], _T]]:  # type: ignore[override]
+        tmp = sc_Set[Union[Tuple[_KT_co, _VT_co], _T]](
+            iter(self),
+            connection=self._parent.connection,
+            serializer=cast(Callable[[Union[Tuple[_KT_co, _VT_co], _T]], bytes], self._item_serializer),
+            deserializer=cast(Callable[[bytes], Union[Tuple[_KT_co, _VT_co], _T]], self._item_deserializer),
+            persist=False,
+        )
+        tmp.symmetric_difference_update(o)
+        return tmp
+
+    def __rxor__(self, o: Iterable[_T]) -> sc_Set[Union[Tuple[_KT_co, _VT_co], _T]]:  # type: ignore[override]
+        return self ^ o
